module ActiveResource
  module VERSION #:nodoc:
    MAJOR = 3
    MINOR = 1
    TINY  = 3
    PRE   = nil

    STRING = [MAJOR, MINOR, TINY, PRE].compact.join('.')
  end
end
